@@ -7,8 +7,9 @@
 '''A simple Twitter client made with pyqt4'''
 
 from utils import *
+from notifications import KhweeteurNotification
 
-__version__ = '0.1.0'
+__version__ = '0.1.2'
 
 class KhweeteurActionWorker(QThread):
 
@@ -625,7 +626,7 @@ class KhweeteurWorker(QThread):
                 self.info.emit(self.error.message)  # fix bug#404
             else:
                 self.info.emit(self.tr('A network error occur'))
-
+        
     def errors(self, error):
         self.error = error
         print 'errors : ', error
@@ -1388,7 +1389,7 @@ class KhweeteurAbout(QMainWindow):
             aboutScrollArea = QScrollArea(self)
             aboutScrollArea.setWidgetResizable(True)
             awidget = QWidget(aboutScrollArea)
-            awidget.setMinimumSize(480, 1200)
+            awidget.setMinimumSize(480, 1300)
             awidget.setSizePolicy(QSizePolicy.Expanding,
                                   QSizePolicy.Expanding)
             aboutScrollArea.setSizePolicy(QSizePolicy.Expanding,
@@ -2192,9 +2193,7 @@ class KhweeteurWin(QMainWindow):
             self.worker.newStatuses.connect(self.tweetsModel.addStatuses)
             self.connect(self.worker, SIGNAL('finished()'),
                          self.refreshEnded)
-            self.notifications.connect(self.worker,
-                    SIGNAL('info(unicode)'),
-                    self.notifications.info)
+            self.worker.info.connect(self.notifications.info)
         else:
             self.worker.geocode = geocode
         self.worker.start()
@@ -2263,6 +2262,9 @@ class KhweeteurWin(QMainWindow):
         fileMenu.addAction(self.tr('&Search'), self.open_search,
                            QKeySequence(self.tr('Ctrl+S', 'Search')))
 
+        fileMenu.addAction(self.tr('&TwitPic Upload'), self.twitpic_upload,
+                           QKeySequence(self.tr('Ctrl+T', 'Twitpic Upload')))
+
         if self.search_keyword != None:
             keywords = self.settings.value('savedSearch')
             if keywords != None:
@@ -2278,6 +2280,29 @@ class KhweeteurWin(QMainWindow):
 
         fileMenu.addAction(self.tr('&About'), self.do_about)
 
+    def twitpic_upload(self):
+        message = 'Test'
+        import twitpic2
+        api = \
+            twitter.Api(username=KHWEETEUR_TWITTER_CONSUMER_KEY,
+                password=KHWEETEUR_TWITTER_CONSUMER_SECRET,
+                access_token_key=str(self.settings.value('twitter_access_token_key'
+                )),
+                access_token_secret=str(self.settings.value('twitter_access_token_secret'
+                )))
+        twitpic = twitpic2.TwitPicOAuthClient(
+            consumer_key = KHWEETEUR_TWITTER_CONSUMER_KEY,
+            consumer_secret = KHWEETEUR_TWITTER_CONSUMER_SECRET,
+            access_token = ACCESS_TOKEN, #FIXME
+            service_key = 'f9b7357e0dc5473df5f141145e4dceb0'
+            )
+        # methods - read, create, update, remove
+        params = []
+        params['media'] = 'khweeteur.png'
+        params['message'] = 'Test of python-twitpic module from #Khweeteur'
+        response = twitpic2.create('upload', params)
+        print response
+        
     def del_search(self):
         keywords = self.settings.value('savedSearch')
         if not keywords:
